#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:logging_level) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-EOD
    Specifies the level of loging for the job.
    Supported values are:
    - `DBMS_SCHEDULER.LOGGING_OFF`
    - `DBMS_SCHEDULER.LOGGING_RUNS`
    - `DBMS_SCHEDULER.LOGGING_FAILED_RUNS`
    - `DBMS_SCHEDULER.LOGGING_FULL`

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          logging_level => 'DBMS_SCHEDULER.LOGGING_FULL',
          ...
        }

    Default value: 'DBMS_SCHEDULER.LOGGING_OFF'

  EOD

  defaultto 'DBMS_SCHEDULER.LOGGING_OFF'

  newvalues('DBMS_SCHEDULER.LOGGING_OFF', 'DBMS_SCHEDULER.LOGGING_RUNS', 'DBMS_SCHEDULER.LOGGING_FAILED_RUNS', 'DBMS_SCHEDULER.LOGGING_FULL')

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('LOGGING_LEVEL')
  end

  on_modify do
    statement = template('ora_config/ora_scheduler_job/modify_unquoted_attribute.sql.erb', binding)
    sql statement, {:sid => resource.sid}
  end

end
