#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:start_date) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-EOD
    Specifies a date and time when this job will be started or scheduled.
    This property is specified in the European date format, ie 'DD-MM-YYYY HH24:Mi:SS'.

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          start_date => '28-04-2018 15:30:00',
          ...
        }

    Puppet doesn't provide a default value.

  EOD

  defaultto ''

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('START_DATE')
  end

  on_modify do
    if resource.start_date == '' or resource.start_date.nil?
      statement = "begin dbms_scheduler.set_attribute_null(name => '#{resource.owner}.#{resource.job_name}', attribute => 'START_DATE'); end;\n/\n"
    else
      statement = template('ora_config/ora_scheduler_job/modify_date_attribute.sql.erb', binding)
    end
    sql statement, {:sid => resource.sid}
  end

end
