#
# See the file "LICENSE" for the full license governing this code.
#
module Puppet_X
  module EnterpriseModules
    module Oracle
      # Docs
      module DatafileProperty
        def self.included(parent)
          parent.send(:include, Puppet_X::EnterpriseModules::Oracle::Access)
          parent.send(:include, Puppet_X::EnterpriseModules::Oracle::Information)
          parent.send(:include, EasyType)
          parent.extend(ClassMethods)
        end

        def file_type
          (resource[:contents] == :temporary) ? 'tempfile' : 'datafile'
        end

        def next_clause
          if resource[:autoextend] == :off
            ""
          else
            if resource[:next]
              "next #{resource[:next]}"
            else
              ""
            end
          end
        end

        def maxsize_clause
          if resource[:max_size]
            "maxsize #{resource[:max_size]}"
          else
            ""
          end
        end

        def autoextend_spec
          if resource[:autoextend] == :on
            "autoextend #{resource[:autoextend]} #{next_clause} #{maxsize_clause}"
          elsif resource[:autoextend].nil?
            ""
          else
            "autoextend #{resource[:autoextend]}"
          end
        end

        def df_array_size(df)
          ( df.nil? or df == :absent ) ? 0 : df.length
        end

        def desired_num_datafiles
          resource.num_datafiles.to_i
        end

        def current_num_datafiles
          provider.num_datafiles.to_i
        end

        def ts_type
          (self['bigfile'] == :yes) ? 'bigfile' : ''
        end

        def ts_contents
          (self['contents'] != :permanent) ? self['contents'] : ''
        end

        def ts_encryption
          if self['encryption'].nil?
            ''
          elsif :true
            "encryption default storage (encrypt)"
          else
            "encryption using '#{encryption}' default storage (encrypt)"
          end
        end

        def after_apply
          nil
        end

        # Docs
        module ClassMethods

        end
      end
    end
  end
end
